# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class AvailableIpPoolSubnet(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gateway': 'str',
        'prefix_length': 'int',
        'enabled': 'bool',
        'ip_ranges': 'IpRanges',
        'total_ip_count': 'int'
    }

    attribute_map = {
        'gateway': 'gateway',
        'prefix_length': 'prefixLength',
        'enabled': 'enabled',
        'ip_ranges': 'ipRanges',
        'total_ip_count': 'totalIpCount'
    }

    def __init__(self, gateway=None, prefix_length=None, enabled=False, ip_ranges=None, total_ip_count=None):
        """
        AvailableIpPoolSubnet - a model defined in Swagger
        """

        self._gateway = None
        self._prefix_length = None
        self._enabled = None
        self._ip_ranges = None
        self._total_ip_count = None

        if gateway is not None:
          self.gateway = gateway
        if prefix_length is not None:
          self.prefix_length = prefix_length
        if enabled is not None:
          self.enabled = enabled
        if ip_ranges is not None:
          self.ip_ranges = ip_ranges
        if total_ip_count is not None:
          self.total_ip_count = total_ip_count

    @property
    def gateway(self):
        """
        Gets the gateway of this AvailableIpPoolSubnet.
        The gateway for the subnet on which IPs are available.

        :return: The gateway of this AvailableIpPoolSubnet.
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """
        Sets the gateway of this AvailableIpPoolSubnet.
        The gateway for the subnet on which IPs are available.

        :param gateway: The gateway of this AvailableIpPoolSubnet.
        :type: str
        """

        self._gateway = gateway

    @property
    def prefix_length(self):
        """
        Gets the prefix_length of this AvailableIpPoolSubnet.
        The netmask prefix length of the subnet.

        :return: The prefix_length of this AvailableIpPoolSubnet.
        :rtype: int
        """
        return self._prefix_length

    @prefix_length.setter
    def prefix_length(self, prefix_length):
        """
        Sets the prefix_length of this AvailableIpPoolSubnet.
        The netmask prefix length of the subnet.

        :param prefix_length: The prefix_length of this AvailableIpPoolSubnet.
        :type: int
        """

        self._prefix_length = prefix_length

    @property
    def enabled(self):
        """
        Gets the enabled of this AvailableIpPoolSubnet.
        Indicates whether the network subnet is currently enabled.

        :return: The enabled of this AvailableIpPoolSubnet.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this AvailableIpPoolSubnet.
        Indicates whether the network subnet is currently enabled.

        :param enabled: The enabled of this AvailableIpPoolSubnet.
        :type: bool
        """

        self._enabled = enabled

    @property
    def ip_ranges(self):
        """
        Gets the ip_ranges of this AvailableIpPoolSubnet.
        Range of IPs which are available for use.

        :return: The ip_ranges of this AvailableIpPoolSubnet.
        :rtype: IpRanges
        """
        return self._ip_ranges

    @ip_ranges.setter
    def ip_ranges(self, ip_ranges):
        """
        Sets the ip_ranges of this AvailableIpPoolSubnet.
        Range of IPs which are available for use.

        :param ip_ranges: The ip_ranges of this AvailableIpPoolSubnet.
        :type: IpRanges
        """

        self._ip_ranges = ip_ranges

    @property
    def total_ip_count(self):
        """
        Gets the total_ip_count of this AvailableIpPoolSubnet.
        The total number of available IP addresses.

        :return: The total_ip_count of this AvailableIpPoolSubnet.
        :rtype: int
        """
        return self._total_ip_count

    @total_ip_count.setter
    def total_ip_count(self, total_ip_count):
        """
        Sets the total_ip_count of this AvailableIpPoolSubnet.
        The total number of available IP addresses.

        :param total_ip_count: The total_ip_count of this AvailableIpPoolSubnet.
        :type: int
        """

        self._total_ip_count = total_ip_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AvailableIpPoolSubnet):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
