# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Cell(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'product_build_date': 'datetime',
        'is_active': 'bool',
        'name': 'str',
        'primary_ip': 'str',
        'product_version': 'str'
    }

    attribute_map = {
        'id': 'id',
        'product_build_date': 'productBuildDate',
        'is_active': 'isActive',
        'name': 'name',
        'primary_ip': 'primaryIP',
        'product_version': 'productVersion'
    }

    def __init__(self, id=None, product_build_date=None, is_active=None, name=None, primary_ip=None, product_version=None):
        """
        Cell - a model defined in Swagger
        """

        self._id = None
        self._product_build_date = None
        self._is_active = None
        self._name = None
        self._primary_ip = None
        self._product_version = None

        if id is not None:
          self.id = id
        if product_build_date is not None:
          self.product_build_date = product_build_date
        if is_active is not None:
          self.is_active = is_active
        if name is not None:
          self.name = name
        if primary_ip is not None:
          self.primary_ip = primary_ip
        if product_version is not None:
          self.product_version = product_version

    @property
    def id(self):
        """
        Gets the id of this Cell.
        The unique id of the cell.

        :return: The id of this Cell.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Cell.
        The unique id of the cell.

        :param id: The id of this Cell.
        :type: str
        """

        self._id = id

    @property
    def product_build_date(self):
        """
        Gets the product_build_date of this Cell.
        The build date for the version of the product installed on this cell.

        :return: The product_build_date of this Cell.
        :rtype: datetime
        """
        return self._product_build_date

    @product_build_date.setter
    def product_build_date(self, product_build_date):
        """
        Sets the product_build_date of this Cell.
        The build date for the version of the product installed on this cell.

        :param product_build_date: The product_build_date of this Cell.
        :type: datetime
        """

        self._product_build_date = product_build_date

    @property
    def is_active(self):
        """
        Gets the is_active of this Cell.
        Cell active state.

        :return: The is_active of this Cell.
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """
        Sets the is_active of this Cell.
        Cell active state.

        :param is_active: The is_active of this Cell.
        :type: bool
        """

        self._is_active = is_active

    @property
    def name(self):
        """
        Gets the name of this Cell.
        The name of the cell.

        :return: The name of this Cell.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Cell.
        The name of the cell.

        :param name: The name of this Cell.
        :type: str
        """

        self._name = name

    @property
    def primary_ip(self):
        """
        Gets the primary_ip of this Cell.
        The primary ip address of the cell.

        :return: The primary_ip of this Cell.
        :rtype: str
        """
        return self._primary_ip

    @primary_ip.setter
    def primary_ip(self, primary_ip):
        """
        Sets the primary_ip of this Cell.
        The primary ip address of the cell.

        :param primary_ip: The primary_ip of this Cell.
        :type: str
        """

        self._primary_ip = primary_ip

    @property
    def product_version(self):
        """
        Gets the product_version of this Cell.
        The product version of the cell.

        :return: The product_version of this Cell.
        :rtype: str
        """
        return self._product_version

    @product_version.setter
    def product_version(self, product_version):
        """
        Sets the product_version of this Cell.
        The product version of the cell.

        :param product_version: The product_version of this Cell.
        :type: str
        """

        self._product_version = product_version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Cell):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
