# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class CustomEntityType(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'vro_id': 'str',
        'vro_dynamic_type': 'str',
        'name': 'str',
        'nss': 'str',
        'description': 'str',
        'tenant_scoped': 'bool',
        'provider_scoped': 'bool',
        'publish_all': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'vro_id': 'vroId',
        'vro_dynamic_type': 'vroDynamicType',
        'name': 'name',
        'nss': 'nss',
        'description': 'description',
        'tenant_scoped': 'tenantScoped',
        'provider_scoped': 'providerScoped',
        'publish_all': 'publishAll'
    }

    def __init__(self, id=None, vro_id=None, vro_dynamic_type=None, name=None, nss=None, description='', tenant_scoped=True, provider_scoped=True, publish_all=False):
        """
        CustomEntityType - a model defined in Swagger
        """

        self._id = None
        self._vro_id = None
        self._vro_dynamic_type = None
        self._name = None
        self._nss = None
        self._description = None
        self._tenant_scoped = None
        self._provider_scoped = None
        self._publish_all = None

        if id is not None:
          self.id = id
        if vro_id is not None:
          self.vro_id = vro_id
        if vro_dynamic_type is not None:
          self.vro_dynamic_type = vro_dynamic_type
        if name is not None:
          self.name = name
        if nss is not None:
          self.nss = nss
        if description is not None:
          self.description = description
        if tenant_scoped is not None:
          self.tenant_scoped = tenant_scoped
        if provider_scoped is not None:
          self.provider_scoped = provider_scoped
        if publish_all is not None:
          self.publish_all = publish_all

    @property
    def id(self):
        """
        Gets the id of this CustomEntityType.
        UUID for custom entity type. This is immutable. 

        :return: The id of this CustomEntityType.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CustomEntityType.
        UUID for custom entity type. This is immutable. 

        :param id: The id of this CustomEntityType.
        :type: str
        """

        self._id = id

    @property
    def vro_id(self):
        """
        Gets the vro_id of this CustomEntityType.

        :return: The vro_id of this CustomEntityType.
        :rtype: str
        """
        return self._vro_id

    @vro_id.setter
    def vro_id(self, vro_id):
        """
        Sets the vro_id of this CustomEntityType.

        :param vro_id: The vro_id of this CustomEntityType.
        :type: str
        """

        self._vro_id = vro_id

    @property
    def vro_dynamic_type(self):
        """
        Gets the vro_dynamic_type of this CustomEntityType.
        This refers to VRO's dynamic type. 

        :return: The vro_dynamic_type of this CustomEntityType.
        :rtype: str
        """
        return self._vro_dynamic_type

    @vro_dynamic_type.setter
    def vro_dynamic_type(self, vro_dynamic_type):
        """
        Sets the vro_dynamic_type of this CustomEntityType.
        This refers to VRO's dynamic type. 

        :param vro_dynamic_type: The vro_dynamic_type of this CustomEntityType.
        :type: str
        """

        self._vro_dynamic_type = vro_dynamic_type

    @property
    def name(self):
        """
        Gets the name of this CustomEntityType.
        Display name. 

        :return: The name of this CustomEntityType.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CustomEntityType.
        Display name. 

        :param name: The name of this CustomEntityType.
        :type: str
        """

        self._name = name

    @property
    def nss(self):
        """
        Gets the nss of this CustomEntityType.
        This refers to a unique namespace specific string. 

        :return: The nss of this CustomEntityType.
        :rtype: str
        """
        return self._nss

    @nss.setter
    def nss(self, nss):
        """
        Sets the nss of this CustomEntityType.
        This refers to a unique namespace specific string. 

        :param nss: The nss of this CustomEntityType.
        :type: str
        """

        self._nss = nss

    @property
    def description(self):
        """
        Gets the description of this CustomEntityType.

        :return: The description of this CustomEntityType.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CustomEntityType.

        :param description: The description of this CustomEntityType.
        :type: str
        """

        self._description = description

    @property
    def tenant_scoped(self):
        """
        Gets the tenant_scoped of this CustomEntityType.

        :return: The tenant_scoped of this CustomEntityType.
        :rtype: bool
        """
        return self._tenant_scoped

    @tenant_scoped.setter
    def tenant_scoped(self, tenant_scoped):
        """
        Sets the tenant_scoped of this CustomEntityType.

        :param tenant_scoped: The tenant_scoped of this CustomEntityType.
        :type: bool
        """

        self._tenant_scoped = tenant_scoped

    @property
    def provider_scoped(self):
        """
        Gets the provider_scoped of this CustomEntityType.

        :return: The provider_scoped of this CustomEntityType.
        :rtype: bool
        """
        return self._provider_scoped

    @provider_scoped.setter
    def provider_scoped(self, provider_scoped):
        """
        Sets the provider_scoped of this CustomEntityType.

        :param provider_scoped: The provider_scoped of this CustomEntityType.
        :type: bool
        """

        self._provider_scoped = provider_scoped

    @property
    def publish_all(self):
        """
        Gets the publish_all of this CustomEntityType.
        Read-only value indicating publishAll state 

        :return: The publish_all of this CustomEntityType.
        :rtype: bool
        """
        return self._publish_all

    @publish_all.setter
    def publish_all(self, publish_all):
        """
        Sets the publish_all of this CustomEntityType.
        Read-only value indicating publishAll state 

        :param publish_all: The publish_all of this CustomEntityType.
        :type: bool
        """

        self._publish_all = publish_all

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomEntityType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
