# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class EdgeGatewayBacking(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'backing_id': 'str',
        'gateway_type': 'EdgeGatewayType',
        'network_provider': 'EntityReference'
    }

    attribute_map = {
        'backing_id': 'backingId',
        'gateway_type': 'gatewayType',
        'network_provider': 'networkProvider'
    }

    def __init__(self, backing_id=None, gateway_type=None, network_provider=None):
        """
        EdgeGatewayBacking - a model defined in Swagger
        """

        self._backing_id = None
        self._gateway_type = None
        self._network_provider = None

        if backing_id is not None:
          self.backing_id = backing_id
        if gateway_type is not None:
          self.gateway_type = gateway_type
        if network_provider is not None:
          self.network_provider = network_provider

    @property
    def backing_id(self):
        """
        Gets the backing_id of this EdgeGatewayBacking.
        The identifier of the edge gateways backing router.

        :return: The backing_id of this EdgeGatewayBacking.
        :rtype: str
        """
        return self._backing_id

    @backing_id.setter
    def backing_id(self, backing_id):
        """
        Sets the backing_id of this EdgeGatewayBacking.
        The identifier of the edge gateways backing router.

        :param backing_id: The backing_id of this EdgeGatewayBacking.
        :type: str
        """

        self._backing_id = backing_id

    @property
    def gateway_type(self):
        """
        Gets the gateway_type of this EdgeGatewayBacking.
        The type of the gateway. Describes if this is an NSX-T edge gateway or an NSX-V edge gateway.

        :return: The gateway_type of this EdgeGatewayBacking.
        :rtype: EdgeGatewayType
        """
        return self._gateway_type

    @gateway_type.setter
    def gateway_type(self, gateway_type):
        """
        Sets the gateway_type of this EdgeGatewayBacking.
        The type of the gateway. Describes if this is an NSX-T edge gateway or an NSX-V edge gateway.

        :param gateway_type: The gateway_type of this EdgeGatewayBacking.
        :type: EdgeGatewayType
        """

        self._gateway_type = gateway_type

    @property
    def network_provider(self):
        """
        Gets the network_provider of this EdgeGatewayBacking.
        The backing network provider, either NSX-T or NSX-V.

        :return: The network_provider of this EdgeGatewayBacking.
        :rtype: EntityReference
        """
        return self._network_provider

    @network_provider.setter
    def network_provider(self, network_provider):
        """
        Sets the network_provider of this EdgeGatewayBacking.
        The backing network provider, either NSX-T or NSX-V.

        :param network_provider: The network_provider of this EdgeGatewayBacking.
        :type: EntityReference
        """

        self._network_provider = network_provider

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, EdgeGatewayBacking):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
