# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class NetworkPoolBacking(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'vlan_id_ranges': 'VlanIdRanges',
        'vds_refs': 'list[BackingRef]',
        'port_group_refs': 'list[BackingRef]',
        'transport_zone_ref': 'BackingRef',
        'provider_ref': 'EntityReference'
    }

    attribute_map = {
        'vlan_id_ranges': 'vlanIdRanges',
        'vds_refs': 'vdsRefs',
        'port_group_refs': 'portGroupRefs',
        'transport_zone_ref': 'transportZoneRef',
        'provider_ref': 'providerRef'
    }

    def __init__(self, vlan_id_ranges=None, vds_refs=None, port_group_refs=None, transport_zone_ref=None, provider_ref=None):
        """
        NetworkPoolBacking - a model defined in Swagger
        """

        self._vlan_id_ranges = None
        self._vds_refs = None
        self._port_group_refs = None
        self._transport_zone_ref = None
        self._provider_ref = None

        if vlan_id_ranges is not None:
          self.vlan_id_ranges = vlan_id_ranges
        if vds_refs is not None:
          self.vds_refs = vds_refs
        if port_group_refs is not None:
          self.port_group_refs = port_group_refs
        if transport_zone_ref is not None:
          self.transport_zone_ref = transport_zone_ref
        if provider_ref is not None:
          self.provider_ref = provider_ref

    @property
    def vlan_id_ranges(self):
        """
        Gets the vlan_id_ranges of this NetworkPoolBacking.
        The range of backing VLAN Id's. This information is available only for VLAN backed network pools. 

        :return: The vlan_id_ranges of this NetworkPoolBacking.
        :rtype: VlanIdRanges
        """
        return self._vlan_id_ranges

    @vlan_id_ranges.setter
    def vlan_id_ranges(self, vlan_id_ranges):
        """
        Sets the vlan_id_ranges of this NetworkPoolBacking.
        The range of backing VLAN Id's. This information is available only for VLAN backed network pools. 

        :param vlan_id_ranges: The vlan_id_ranges of this NetworkPoolBacking.
        :type: VlanIdRanges
        """

        self._vlan_id_ranges = vlan_id_ranges

    @property
    def vds_refs(self):
        """
        Gets the vds_refs of this NetworkPoolBacking.
        The information about virtual distributed switches. This information is available only for VLAN, VXLAN and Universal VXLAN backed network pools. 

        :return: The vds_refs of this NetworkPoolBacking.
        :rtype: list[BackingRef]
        """
        return self._vds_refs

    @vds_refs.setter
    def vds_refs(self, vds_refs):
        """
        Sets the vds_refs of this NetworkPoolBacking.
        The information about virtual distributed switches. This information is available only for VLAN, VXLAN and Universal VXLAN backed network pools. 

        :param vds_refs: The vds_refs of this NetworkPoolBacking.
        :type: list[BackingRef]
        """

        self._vds_refs = vds_refs

    @property
    def port_group_refs(self):
        """
        Gets the port_group_refs of this NetworkPoolBacking.
        All the vSphere port groups that will be used by this network pool. This information is available only for Portgroup backed network pools. 

        :return: The port_group_refs of this NetworkPoolBacking.
        :rtype: list[BackingRef]
        """
        return self._port_group_refs

    @port_group_refs.setter
    def port_group_refs(self, port_group_refs):
        """
        Sets the port_group_refs of this NetworkPoolBacking.
        All the vSphere port groups that will be used by this network pool. This information is available only for Portgroup backed network pools. 

        :param port_group_refs: The port_group_refs of this NetworkPoolBacking.
        :type: list[BackingRef]
        """

        self._port_group_refs = port_group_refs

    @property
    def transport_zone_ref(self):
        """
        Gets the transport_zone_ref of this NetworkPoolBacking.
        The Id of the backing transport zone in NSX. 

        :return: The transport_zone_ref of this NetworkPoolBacking.
        :rtype: BackingRef
        """
        return self._transport_zone_ref

    @transport_zone_ref.setter
    def transport_zone_ref(self, transport_zone_ref):
        """
        Sets the transport_zone_ref of this NetworkPoolBacking.
        The Id of the backing transport zone in NSX. 

        :param transport_zone_ref: The transport_zone_ref of this NetworkPoolBacking.
        :type: BackingRef
        """

        self._transport_zone_ref = transport_zone_ref

    @property
    def provider_ref(self):
        """
        Gets the provider_ref of this NetworkPoolBacking.
        The Id of vCenter server or the NSX-T manager that owns this backing entity.

        :return: The provider_ref of this NetworkPoolBacking.
        :rtype: EntityReference
        """
        return self._provider_ref

    @provider_ref.setter
    def provider_ref(self, provider_ref):
        """
        Sets the provider_ref of this NetworkPoolBacking.
        The Id of vCenter server or the NSX-T manager that owns this backing entity.

        :param provider_ref: The provider_ref of this NetworkPoolBacking.
        :type: EntityReference
        """

        self._provider_ref = provider_ref

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, NetworkPoolBacking):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
