# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ProviderVdc(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'is_enabled': 'bool',
        'max_supported_hw_version': 'str',
        'nsx_t_manager': 'EntityReference',
        'vim_server': 'EntityReference'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'is_enabled': 'isEnabled',
        'max_supported_hw_version': 'maxSupportedHwVersion',
        'nsx_t_manager': 'nsxTManager',
        'vim_server': 'vimServer'
    }

    def __init__(self, id=None, name=None, description=None, is_enabled=None, max_supported_hw_version=None, nsx_t_manager=None, vim_server=None):
        """
        ProviderVdc - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._description = None
        self._is_enabled = None
        self._max_supported_hw_version = None
        self._nsx_t_manager = None
        self._vim_server = None

        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if description is not None:
          self.description = description
        if is_enabled is not None:
          self.is_enabled = is_enabled
        if max_supported_hw_version is not None:
          self.max_supported_hw_version = max_supported_hw_version
        if nsx_t_manager is not None:
          self.nsx_t_manager = nsx_t_manager
        if vim_server is not None:
          self.vim_server = vim_server

    @property
    def id(self):
        """
        Gets the id of this ProviderVdc.
        A unique identifier for the pvdc.

        :return: The id of this ProviderVdc.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ProviderVdc.
        A unique identifier for the pvdc.

        :param id: The id of this ProviderVdc.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ProviderVdc.
        The name of the pvdc.

        :return: The name of this ProviderVdc.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ProviderVdc.
        The name of the pvdc.

        :param name: The name of this ProviderVdc.
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ProviderVdc.
        The description of the pvdc.

        :return: The description of this ProviderVdc.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ProviderVdc.
        The description of the pvdc.

        :param description: The description of this ProviderVdc.
        :type: str
        """

        self._description = description

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this ProviderVdc.
        Whether the pvdc is enabled or not.

        :return: The is_enabled of this ProviderVdc.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this ProviderVdc.
        Whether the pvdc is enabled or not.

        :param is_enabled: The is_enabled of this ProviderVdc.
        :type: bool
        """

        self._is_enabled = is_enabled

    @property
    def max_supported_hw_version(self):
        """
        Gets the max_supported_hw_version of this ProviderVdc.
        The maximum hardware version this pvdc supports.

        :return: The max_supported_hw_version of this ProviderVdc.
        :rtype: str
        """
        return self._max_supported_hw_version

    @max_supported_hw_version.setter
    def max_supported_hw_version(self, max_supported_hw_version):
        """
        Sets the max_supported_hw_version of this ProviderVdc.
        The maximum hardware version this pvdc supports.

        :param max_supported_hw_version: The max_supported_hw_version of this ProviderVdc.
        :type: str
        """

        self._max_supported_hw_version = max_supported_hw_version

    @property
    def nsx_t_manager(self):
        """
        Gets the nsx_t_manager of this ProviderVdc.
        The NSX-T manager of the pvdc, if any.

        :return: The nsx_t_manager of this ProviderVdc.
        :rtype: EntityReference
        """
        return self._nsx_t_manager

    @nsx_t_manager.setter
    def nsx_t_manager(self, nsx_t_manager):
        """
        Sets the nsx_t_manager of this ProviderVdc.
        The NSX-T manager of the pvdc, if any.

        :param nsx_t_manager: The nsx_t_manager of this ProviderVdc.
        :type: EntityReference
        """

        self._nsx_t_manager = nsx_t_manager

    @property
    def vim_server(self):
        """
        Gets the vim_server of this ProviderVdc.
        The vCenter server the pvdc belongs to.

        :return: The vim_server of this ProviderVdc.
        :rtype: EntityReference
        """
        return self._vim_server

    @vim_server.setter
    def vim_server(self, vim_server):
        """
        Sets the vim_server of this ProviderVdc.
        The vCenter server the pvdc belongs to.

        :param vim_server: The vim_server of this ProviderVdc.
        :type: EntityReference
        """

        self._vim_server = vim_server

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ProviderVdc):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
