# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PublishableRightsMapping(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'id': 'str',
        'description': 'str',
        'bundle_key': 'str',
        'read_only': 'bool',
        'publish_all': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'description': 'description',
        'bundle_key': 'bundleKey',
        'read_only': 'readOnly',
        'publish_all': 'publishAll'
    }

    def __init__(self, name=None, id=None, description=None, bundle_key=None, read_only=None, publish_all=False):
        """
        PublishableRightsMapping - a model defined in Swagger
        """

        self._name = None
        self._id = None
        self._description = None
        self._bundle_key = None
        self._read_only = None
        self._publish_all = None

        self.name = name
        if id is not None:
          self.id = id
        self.description = description
        if bundle_key is not None:
          self.bundle_key = bundle_key
        if read_only is not None:
          self.read_only = read_only
        if publish_all is not None:
          self.publish_all = publish_all

    @property
    def name(self):
        """
        Gets the name of this PublishableRightsMapping.

        :return: The name of this PublishableRightsMapping.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PublishableRightsMapping.

        :param name: The name of this PublishableRightsMapping.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")
        if name is not None and len(name) > 128:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `128`")
        if name is not None and len(name) < 1:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")

        self._name = name

    @property
    def id(self):
        """
        Gets the id of this PublishableRightsMapping.

        :return: The id of this PublishableRightsMapping.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PublishableRightsMapping.

        :param id: The id of this PublishableRightsMapping.
        :type: str
        """
        if id is not None and len(id) > 128:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `128`")

        self._id = id

    @property
    def description(self):
        """
        Gets the description of this PublishableRightsMapping.

        :return: The description of this PublishableRightsMapping.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this PublishableRightsMapping.

        :param description: The description of this PublishableRightsMapping.
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")
        if description is not None and len(description) > 256:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")
        if description is not None and len(description) < 1:
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `1`")

        self._description = description

    @property
    def bundle_key(self):
        """
        Gets the bundle_key of this PublishableRightsMapping.

        :return: The bundle_key of this PublishableRightsMapping.
        :rtype: str
        """
        return self._bundle_key

    @bundle_key.setter
    def bundle_key(self, bundle_key):
        """
        Sets the bundle_key of this PublishableRightsMapping.

        :param bundle_key: The bundle_key of this PublishableRightsMapping.
        :type: str
        """
        if bundle_key is not None and len(bundle_key) > 128:
            raise ValueError("Invalid value for `bundle_key`, length must be less than or equal to `128`")
        if bundle_key is not None and len(bundle_key) < 1:
            raise ValueError("Invalid value for `bundle_key`, length must be greater than or equal to `1`")

        self._bundle_key = bundle_key

    @property
    def read_only(self):
        """
        Gets the read_only of this PublishableRightsMapping.

        :return: The read_only of this PublishableRightsMapping.
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """
        Sets the read_only of this PublishableRightsMapping.

        :param read_only: The read_only of this PublishableRightsMapping.
        :type: bool
        """

        self._read_only = read_only

    @property
    def publish_all(self):
        """
        Gets the publish_all of this PublishableRightsMapping.
        Read-only value indicating publishAll state 

        :return: The publish_all of this PublishableRightsMapping.
        :rtype: bool
        """
        return self._publish_all

    @publish_all.setter
    def publish_all(self, publish_all):
        """
        Sets the publish_all of this PublishableRightsMapping.
        Read-only value indicating publishAll state 

        :param publish_all: The publish_all of this PublishableRightsMapping.
        :type: bool
        """

        self._publish_all = publish_all

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PublishableRightsMapping):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
