# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ServiceApp(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'client_id': 'str',
        'client_secret': 'str',
        'org_id': 'str',
        'service_scope': 'ServiceAppScope',
        'access_token_ttl': 'int',
        'access_token_expiration': 'datetime',
        'enabled': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'client_id': 'clientId',
        'client_secret': 'clientSecret',
        'org_id': 'orgId',
        'service_scope': 'serviceScope',
        'access_token_ttl': 'accessTokenTTL',
        'access_token_expiration': 'accessTokenExpiration',
        'enabled': 'enabled'
    }

    def __init__(self, id=None, name=None, client_id=None, client_secret=None, org_id=None, service_scope=None, access_token_ttl=None, access_token_expiration=None, enabled=True):
        """
        ServiceApp - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._client_id = None
        self._client_secret = None
        self._org_id = None
        self._service_scope = None
        self._access_token_ttl = None
        self._access_token_expiration = None
        self._enabled = None

        if id is not None:
          self.id = id
        self.name = name
        self.client_id = client_id
        self.client_secret = client_secret
        if org_id is not None:
          self.org_id = org_id
        self.service_scope = service_scope
        if access_token_ttl is not None:
          self.access_token_ttl = access_token_ttl
        if access_token_expiration is not None:
          self.access_token_expiration = access_token_expiration
        if enabled is not None:
          self.enabled = enabled

    @property
    def id(self):
        """
        Gets the id of this ServiceApp.
        The unique ID for the service application. This field is read-only.

        :return: The id of this ServiceApp.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ServiceApp.
        The unique ID for the service application. This field is read-only.

        :param id: The id of this ServiceApp.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ServiceApp.
        The name of the service application

        :return: The name of this ServiceApp.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ServiceApp.
        The name of the service application

        :param name: The name of this ServiceApp.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def client_id(self):
        """
        Gets the client_id of this ServiceApp.
        The client ID

        :return: The client_id of this ServiceApp.
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """
        Sets the client_id of this ServiceApp.
        The client ID

        :param client_id: The client_id of this ServiceApp.
        :type: str
        """
        if client_id is None:
            raise ValueError("Invalid value for `client_id`, must not be `None`")

        self._client_id = client_id

    @property
    def client_secret(self):
        """
        Gets the client_secret of this ServiceApp.
        The client secret

        :return: The client_secret of this ServiceApp.
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """
        Sets the client_secret of this ServiceApp.
        The client secret

        :param client_secret: The client_secret of this ServiceApp.
        :type: str
        """
        if client_secret is None:
            raise ValueError("Invalid value for `client_secret`, must not be `None`")

        self._client_secret = client_secret

    @property
    def org_id(self):
        """
        Gets the org_id of this ServiceApp.
        The external organization id of the service application

        :return: The org_id of this ServiceApp.
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """
        Sets the org_id of this ServiceApp.
        The external organization id of the service application

        :param org_id: The org_id of this ServiceApp.
        :type: str
        """

        self._org_id = org_id

    @property
    def service_scope(self):
        """
        Gets the service_scope of this ServiceApp.
        The scope of the service application

        :return: The service_scope of this ServiceApp.
        :rtype: ServiceAppScope
        """
        return self._service_scope

    @service_scope.setter
    def service_scope(self, service_scope):
        """
        Sets the service_scope of this ServiceApp.
        The scope of the service application

        :param service_scope: The service_scope of this ServiceApp.
        :type: ServiceAppScope
        """
        if service_scope is None:
            raise ValueError("Invalid value for `service_scope`, must not be `None`")

        self._service_scope = service_scope

    @property
    def access_token_ttl(self):
        """
        Gets the access_token_ttl of this ServiceApp.
        The read-only time-to-live of the access token in seconds.

        :return: The access_token_ttl of this ServiceApp.
        :rtype: int
        """
        return self._access_token_ttl

    @access_token_ttl.setter
    def access_token_ttl(self, access_token_ttl):
        """
        Sets the access_token_ttl of this ServiceApp.
        The read-only time-to-live of the access token in seconds.

        :param access_token_ttl: The access_token_ttl of this ServiceApp.
        :type: int
        """

        self._access_token_ttl = access_token_ttl

    @property
    def access_token_expiration(self):
        """
        Gets the access_token_expiration of this ServiceApp.
        The read-only expiration date of the access token.

        :return: The access_token_expiration of this ServiceApp.
        :rtype: datetime
        """
        return self._access_token_expiration

    @access_token_expiration.setter
    def access_token_expiration(self, access_token_expiration):
        """
        Sets the access_token_expiration of this ServiceApp.
        The read-only expiration date of the access token.

        :param access_token_expiration: The access_token_expiration of this ServiceApp.
        :type: datetime
        """

        self._access_token_expiration = access_token_expiration

    @property
    def enabled(self):
        """
        Gets the enabled of this ServiceApp.
        Whether the application is currently enabled.

        :return: The enabled of this ServiceApp.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ServiceApp.
        Whether the application is currently enabled.

        :param enabled: The enabled of this ServiceApp.
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServiceApp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
