# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class UiPluginMetadata(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'plugin_name': 'str',
        'vendor': 'str',
        'description': 'str',
        'version': 'str',
        'license': 'str',
        'link': 'str',
        'tenant_scoped': 'bool',
        'provider_scoped': 'bool',
        'enabled': 'bool'
    }

    attribute_map = {
        'plugin_name': 'pluginName',
        'vendor': 'vendor',
        'description': 'description',
        'version': 'version',
        'license': 'license',
        'link': 'link',
        'tenant_scoped': 'tenant_scoped',
        'provider_scoped': 'provider_scoped',
        'enabled': 'enabled'
    }

    def __init__(self, plugin_name=None, vendor=None, description=None, version=None, license=None, link=None, tenant_scoped=None, provider_scoped=None, enabled=None):
        """
        UiPluginMetadata - a model defined in Swagger
        """

        self._plugin_name = None
        self._vendor = None
        self._description = None
        self._version = None
        self._license = None
        self._link = None
        self._tenant_scoped = None
        self._provider_scoped = None
        self._enabled = None

        self.plugin_name = plugin_name
        self.vendor = vendor
        if description is not None:
          self.description = description
        self.version = version
        self.license = license
        self.link = link
        if tenant_scoped is not None:
          self.tenant_scoped = tenant_scoped
        if provider_scoped is not None:
          self.provider_scoped = provider_scoped
        if enabled is not None:
          self.enabled = enabled

    @property
    def plugin_name(self):
        """
        Gets the plugin_name of this UiPluginMetadata.

        :return: The plugin_name of this UiPluginMetadata.
        :rtype: str
        """
        return self._plugin_name

    @plugin_name.setter
    def plugin_name(self, plugin_name):
        """
        Sets the plugin_name of this UiPluginMetadata.

        :param plugin_name: The plugin_name of this UiPluginMetadata.
        :type: str
        """
        if plugin_name is None:
            raise ValueError("Invalid value for `plugin_name`, must not be `None`")

        self._plugin_name = plugin_name

    @property
    def vendor(self):
        """
        Gets the vendor of this UiPluginMetadata.

        :return: The vendor of this UiPluginMetadata.
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """
        Sets the vendor of this UiPluginMetadata.

        :param vendor: The vendor of this UiPluginMetadata.
        :type: str
        """
        if vendor is None:
            raise ValueError("Invalid value for `vendor`, must not be `None`")

        self._vendor = vendor

    @property
    def description(self):
        """
        Gets the description of this UiPluginMetadata.

        :return: The description of this UiPluginMetadata.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UiPluginMetadata.

        :param description: The description of this UiPluginMetadata.
        :type: str
        """

        self._description = description

    @property
    def version(self):
        """
        Gets the version of this UiPluginMetadata.

        :return: The version of this UiPluginMetadata.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this UiPluginMetadata.

        :param version: The version of this UiPluginMetadata.
        :type: str
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version

    @property
    def license(self):
        """
        Gets the license of this UiPluginMetadata.

        :return: The license of this UiPluginMetadata.
        :rtype: str
        """
        return self._license

    @license.setter
    def license(self, license):
        """
        Sets the license of this UiPluginMetadata.

        :param license: The license of this UiPluginMetadata.
        :type: str
        """
        if license is None:
            raise ValueError("Invalid value for `license`, must not be `None`")

        self._license = license

    @property
    def link(self):
        """
        Gets the link of this UiPluginMetadata.

        :return: The link of this UiPluginMetadata.
        :rtype: str
        """
        return self._link

    @link.setter
    def link(self, link):
        """
        Sets the link of this UiPluginMetadata.

        :param link: The link of this UiPluginMetadata.
        :type: str
        """
        if link is None:
            raise ValueError("Invalid value for `link`, must not be `None`")

        self._link = link

    @property
    def tenant_scoped(self):
        """
        Gets the tenant_scoped of this UiPluginMetadata.

        :return: The tenant_scoped of this UiPluginMetadata.
        :rtype: bool
        """
        return self._tenant_scoped

    @tenant_scoped.setter
    def tenant_scoped(self, tenant_scoped):
        """
        Sets the tenant_scoped of this UiPluginMetadata.

        :param tenant_scoped: The tenant_scoped of this UiPluginMetadata.
        :type: bool
        """

        self._tenant_scoped = tenant_scoped

    @property
    def provider_scoped(self):
        """
        Gets the provider_scoped of this UiPluginMetadata.

        :return: The provider_scoped of this UiPluginMetadata.
        :rtype: bool
        """
        return self._provider_scoped

    @provider_scoped.setter
    def provider_scoped(self, provider_scoped):
        """
        Sets the provider_scoped of this UiPluginMetadata.

        :param provider_scoped: The provider_scoped of this UiPluginMetadata.
        :type: bool
        """

        self._provider_scoped = provider_scoped

    @property
    def enabled(self):
        """
        Gets the enabled of this UiPluginMetadata.

        :return: The enabled of this UiPluginMetadata.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this UiPluginMetadata.

        :param enabled: The enabled of this UiPluginMetadata.
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, UiPluginMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
