# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class UniversalRouter(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'vdc_group_ref': 'EntityReference',
        'local_egress': 'bool',
        'status': 'VdcGroupEntityStatus',
        'error_message': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'vdc_group_ref': 'vdcGroupRef',
        'local_egress': 'localEgress',
        'status': 'status',
        'error_message': 'errorMessage'
    }

    def __init__(self, id=None, name=None, description=None, vdc_group_ref=None, local_egress=None, status=None, error_message=None):
        """
        UniversalRouter - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._description = None
        self._vdc_group_ref = None
        self._local_egress = None
        self._status = None
        self._error_message = None

        if id is not None:
          self.id = id
        self.name = name
        if description is not None:
          self.description = description
        self.vdc_group_ref = vdc_group_ref
        if local_egress is not None:
          self.local_egress = local_egress
        if status is not None:
          self.status = status
        if error_message is not None:
          self.error_message = error_message

    @property
    def id(self):
        """
        Gets the id of this UniversalRouter.

        :return: The id of this UniversalRouter.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UniversalRouter.

        :param id: The id of this UniversalRouter.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this UniversalRouter.

        :return: The name of this UniversalRouter.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UniversalRouter.

        :param name: The name of this UniversalRouter.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def description(self):
        """
        Gets the description of this UniversalRouter.

        :return: The description of this UniversalRouter.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UniversalRouter.

        :param description: The description of this UniversalRouter.
        :type: str
        """

        self._description = description

    @property
    def vdc_group_ref(self):
        """
        Gets the vdc_group_ref of this UniversalRouter.

        :return: The vdc_group_ref of this UniversalRouter.
        :rtype: EntityReference
        """
        return self._vdc_group_ref

    @vdc_group_ref.setter
    def vdc_group_ref(self, vdc_group_ref):
        """
        Sets the vdc_group_ref of this UniversalRouter.

        :param vdc_group_ref: The vdc_group_ref of this UniversalRouter.
        :type: EntityReference
        """
        if vdc_group_ref is None:
            raise ValueError("Invalid value for `vdc_group_ref`, must not be `None`")

        self._vdc_group_ref = vdc_group_ref

    @property
    def local_egress(self):
        """
        Gets the local_egress of this UniversalRouter.

        :return: The local_egress of this UniversalRouter.
        :rtype: bool
        """
        return self._local_egress

    @local_egress.setter
    def local_egress(self, local_egress):
        """
        Sets the local_egress of this UniversalRouter.

        :param local_egress: The local_egress of this UniversalRouter.
        :type: bool
        """

        self._local_egress = local_egress

    @property
    def status(self):
        """
        Gets the status of this UniversalRouter.

        :return: The status of this UniversalRouter.
        :rtype: VdcGroupEntityStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this UniversalRouter.

        :param status: The status of this UniversalRouter.
        :type: VdcGroupEntityStatus
        """

        self._status = status

    @property
    def error_message(self):
        """
        Gets the error_message of this UniversalRouter.

        :return: The error_message of this UniversalRouter.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this UniversalRouter.

        :param error_message: The error_message of this UniversalRouter.
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, UniversalRouter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
