# coding: utf-8

"""
    vCloud Director OpenAPI

    vCloud Director OpenAPI is a new vCloud Director API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy vCloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy vCD operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following vCD error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>vCloud OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom vCloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy vCloud APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       vCloud APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       vCloud APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 33.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class VmcSddcs(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'result_total': 'int',
        'page_count': 'int',
        'page': 'int',
        'page_size': 'int',
        'associations': 'list[Association]',
        'values': 'list[VmcSddc]'
    }

    attribute_map = {
        'result_total': 'resultTotal',
        'page_count': 'pageCount',
        'page': 'page',
        'page_size': 'pageSize',
        'associations': 'associations',
        'values': 'values'
    }

    def __init__(self, result_total=None, page_count=None, page=None, page_size=None, associations=None, values=None):
        """
        VmcSddcs - a model defined in Swagger
        """

        self._result_total = None
        self._page_count = None
        self._page = None
        self._page_size = None
        self._associations = None
        self._values = None

        if result_total is not None:
          self.result_total = result_total
        if page_count is not None:
          self.page_count = page_count
        if page is not None:
          self.page = page
        if page_size is not None:
          self.page_size = page_size
        if associations is not None:
          self.associations = associations
        if values is not None:
          self.values = values

    @property
    def result_total(self):
        """
        Gets the result_total of this VmcSddcs.
        How many results there are in total (i.e., considering all pages).

        :return: The result_total of this VmcSddcs.
        :rtype: int
        """
        return self._result_total

    @result_total.setter
    def result_total(self, result_total):
        """
        Sets the result_total of this VmcSddcs.
        How many results there are in total (i.e., considering all pages).

        :param result_total: The result_total of this VmcSddcs.
        :type: int
        """

        self._result_total = result_total

    @property
    def page_count(self):
        """
        Gets the page_count of this VmcSddcs.
        How many pages there are in total.

        :return: The page_count of this VmcSddcs.
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """
        Sets the page_count of this VmcSddcs.
        How many pages there are in total.

        :param page_count: The page_count of this VmcSddcs.
        :type: int
        """

        self._page_count = page_count

    @property
    def page(self):
        """
        Gets the page of this VmcSddcs.
        The page that was fetched, 1-indexed.

        :return: The page of this VmcSddcs.
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """
        Sets the page of this VmcSddcs.
        The page that was fetched, 1-indexed.

        :param page: The page of this VmcSddcs.
        :type: int
        """

        self._page = page

    @property
    def page_size(self):
        """
        Gets the page_size of this VmcSddcs.
        Result count for page that was fetched.

        :return: The page_size of this VmcSddcs.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this VmcSddcs.
        Result count for page that was fetched.

        :param page_size: The page_size of this VmcSddcs.
        :type: int
        """

        self._page_size = page_size

    @property
    def associations(self):
        """
        Gets the associations of this VmcSddcs.
        Association info for each result.

        :return: The associations of this VmcSddcs.
        :rtype: list[Association]
        """
        return self._associations

    @associations.setter
    def associations(self, associations):
        """
        Sets the associations of this VmcSddcs.
        Association info for each result.

        :param associations: The associations of this VmcSddcs.
        :type: list[Association]
        """

        self._associations = associations

    @property
    def values(self):
        """
        Gets the values of this VmcSddcs.

        :return: The values of this VmcSddcs.
        :rtype: list[VmcSddc]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this VmcSddcs.

        :param values: The values of this VmcSddcs.
        :type: list[VmcSddc]
        """

        self._values = values

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, VmcSddcs):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
